@@ -6,10 +6,14 @@ Advanced Interface Switcher
 System menu plugin class
 '''
 
-import gobject, gtk, hildon
+import gobject
+import gtk
+
+import hildon
 from hildondesktop import StatusMenuItem
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
+
 from advpowcommon.ui.Cachers import DITPixbufCacher
 from advpowcommon.ui.Animation import DITPBCachedAnimator
 from advpowcommon.ui.Config import ConfigUIMaemo5
@@ -23,8 +27,8 @@ import advifswlib.util.locale as locale
 
 class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
-  app_name= 'Advanced Interface Switcher'
-  version = '0.3.8'
+  app_name = 'Advanced Interface Switcher'
+  version = '0.3.9'
   dev_author = 'Kirill Plyashkevich'
   dev_email = 'ru.spirit@gmail.com'
   dev_years = '2010-2011'
@@ -39,7 +43,9 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     self.__config = config.get()
     self.__config_ui = ConfigUIMaemo5()
     self.__sai_cacher = DITPixbufCacher(18)
-    self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, cacher=self.__sai_cacher, time_out=1000)
+    self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, 
+                                              cacher=self.__sai_cacher, 
+                                              time_out=1000)
     self.__m_loop = DBusGMainLoop()
     self.__bus = dbus.SystemBus(mainloop = self.__m_loop, private = True)
 
@@ -52,10 +58,15 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     loaded_ifaces = 0
     for iface in ilist:
       try:
-        self.__interfaces.append(iface[1](self.__bus, self.process_sai, self.__show_settings_dialog))
-        self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), iface[0], iface[0]+1, 0, 1, gtk.EXPAND | gtk.FILL, gtk.SHRINK)
+        self.__interfaces.append(iface[1](self.__bus, self.process_sai, 
+                                          self.__show_settings_dialog))
+        self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), 
+                              iface[0], iface[0]+1, 0, 1, 
+                              gtk.EXPAND | gtk.FILL, 
+                              gtk.SHRINK)
         loaded_ifaces += 1
-        loaded_list = '%s\n%s' % (loaded_list, self.__interfaces[iface[0]].get_name())
+        loaded_list = '%s\n%s' % (loaded_list, 
+                                  self.__interfaces[iface[0]].get_name())
       except Exception, e:
         loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
         pass
@@ -64,10 +75,13 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
   def __show_settings_dialog(self, button=None):
     self.__config.load()
-    settings_dialog = gtk.Dialog('%s' % (self.app_name), None, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, self.__config_ui.get_dialog_buttons())
+    settings_dialog = gtk.Dialog('%s' % (self.app_name), None, 
+                                 gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
+                                 self.__config_ui.get_dialog_buttons())
     wpa = gtk.VBox()
     config_controls = {}
-    config_keys = [key for key in self.__config.get_keys() if key.startswith('settings')]
+    config_keys = [key for key in self.__config.get_keys() 
+                   if key.startswith('settings')]
     config_keys.sort()
     for config_key in config_keys:
       name, ck_type, value = self.__config.get_entry(config_key)
@@ -75,20 +89,30 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
       options = ()
       if config_options:
         options = zip(map(self.__lcl.get, config_options), config_options)
-      config_control = self.__config_ui.create_control(self.__lcl.get(config_key), ck_type, (self.__lcl.get(str(value)), value), options)
+      config_control = self.__config_ui.create_control(self.__lcl.get(config_key), 
+                                                       ck_type, 
+                                                       (self.__lcl.get(str(value)), 
+                                                        value), 
+                                                       options)
       if config_control:
         config_controls[config_key] = config_control
         wpa.pack_start(config_control, False)
 
     about_page = gtk.VBox()
     about_page.pack_start(gtk.Label('%s %s' % (self.app_name, self.version)))
-    about_page.pack_start(gtk.Label('%s%s %s <%s>' % (u'\u00A9', self.dev_years, self.dev_author, self.dev_email)))
-
-    settings_dialog.show_all()
+    about_page.pack_start(gtk.Label('%s%s %s <%s>' % (u'\u00A9', 
+                                                      self.dev_years, 
+                                                      self.dev_author, 
+                                                      self.dev_email)))
     notebook = NotebookMaemo5()
     notebook.set_box(settings_dialog.vbox)
-    notebook.append_items(([[self.__gtk_swr.get_text(gtk.STOCK_PREFERENCES), wpa], [self.__gtk_swr.get_text(gtk.STOCK_ABOUT), about_page]]))
-    settings_dialog.vbox.set_size_request(-1, min(350, notebook.get_height()))
+    notebook.append_pages(([[self.__gtk_swr.get_text(gtk.STOCK_PREFERENCES), 
+                             wpa], 
+                            [self.__gtk_swr.get_text(gtk.STOCK_ABOUT), 
+                             about_page]]))
+#    settings_dialog.vbox.set_size_request(-1, min(350, notebook.get_height()))
+    settings_dialog.show_all()
+    notebook.set_active(0)
     response = settings_dialog.run()
 
     if response == gtk.RESPONSE_OK:
@@ -96,7 +120,8 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
       for config_key in config_keys:
         if config_key in controls_keys:
           name, ck_type, value = self.__config.get_entry(config_key)
-          value = self.__config_ui.get_value(config_controls[config_key], value, ck_type)
+          value = self.__config_ui.get_value(config_controls[config_key], 
+                                             value, ck_type)
           self.__config.set_value(config_key, value)
       self.__config.save()
     settings_dialog.destroy()
