@@ -17,7 +17,8 @@ import advifswlib.util.locale as locale
 
 class AbstractInterface():
 
-  def __init__(self, bus=None, cb_status_area=None, cb_show_settings_dialog=None):
+  def __init__(self, bus=None, cb_status_area=None, 
+               cb_show_settings_dialog=None):
     self.__name = 'IFace'
     self.__processing = False
     self.__bus = bus
@@ -32,19 +33,23 @@ class AbstractInterface():
     self.pre_init()
     self.__name = self.state['name']
     self.__config_path = 'settings/%s' % (self.__name.lower())
-    self.__button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+    self.__button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, 
+                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
     self.__button.set_image(gtk.Image())
-    self.__button.set_image_position(gtk.POS_LEFT)
+    #self.__button.set_image_position(gtk.POS_LEFT|gtk.POS_RIGHT)
     self.__button.set_alignment(0.5,0.5,1,1)
-    self.__button.set_image_alignment(0.5,0.5)
-    self.__button.set_title_alignment(0,0.5)
-    self.__button.set_value_alignment(0,0.5)
+    #self.__button.set_image_alignment(0.5,0.5)
+    #self.__button.set_title_alignment(0,0.5)
+    #self.__button.set_value_alignment(0,0.5)
     self.__button.connect('clicked', self.__button_clicked)
     self.__button.tap_and_hold_setup(None, None, 0)
     self.__button.connect('tap-and-hold', self.__button_tap_and_hold)
     self.__button.connect('destroy', self.__destroy)
     self.__smi_cacher = cacher.get()
-    self.__smi_animator = DITPBCachedAnimator([], self.__button.get_image().set_from_pixbuf, cacher=self.__smi_cacher, time_out=250)
+    self.__smi_animator = DITPBCachedAnimator([], 
+                                              self.__button.get_image().set_from_pixbuf, 
+                                              cacher=self.__smi_cacher, 
+                                              time_out=250)
     self.state_control = None
     self.mode_control = None
 
@@ -105,7 +110,12 @@ class AbstractInterface():
     try:
       def callback(*args, **kwargs): self.__received_signal(x, *args, **kwargs)
       setattr(self, 'received_%s' % x, callback)
-      self.state['dbus'][x]['match'] = self.__bus.add_signal_receiver(getattr(self, 'received_%s' % x), signal_name=self.state['dbus'][x]['name'], dbus_interface=self.state['dbus'][x]['iface'], path=self.state['dbus'][x]['path'], **self.state['dbus'][x]['args'])
+      self.state['dbus'][x]['match'] = self.__bus\
+                                       .add_signal_receiver(getattr(self, 'received_%s' % x), 
+                                                            signal_name=self.state['dbus'][x]['name'], 
+                                                            dbus_interface=self.state['dbus'][x]['iface'], 
+                                                            path=self.state['dbus'][x]['path'], 
+                                                            **self.state['dbus'][x]['args'])
     except:
       pass
 
@@ -143,9 +153,11 @@ class AbstractInterface():
     if update_ui: self.__update_ui()
     windex = self.state['value']
     if self.get_config_value('show-popups') and show_banner and self.state['banner'][windex]:
-      text = '%s: %s' % (self.__name, self.__lcl.get_item(self.state['text'][windex]))
+      text = '%s: %s' % \
+             (self.__name, self.__lcl.get_item(self.state['text'][windex]))
       if len(self.state['modes']) > 1:
-        text = '%s (%s)' % (text, self.__lcl.get(self.state['modes'][self.state['mode']]))
+        text = '%s (%s)' % \
+               (text, self.__lcl.get(self.state['modes'][self.state['mode']]))
       HildonBanner.show_information(self.__button, text)
 
   def __init_interfaces(self):
@@ -155,9 +167,16 @@ class AbstractInterface():
     try:
       loaded = True
       if self.interfaces[x][3] and not force:
-          loaded = get_shell_command_output('ps aux | grep \'%s\' | grep -v \'grep\' | awk {\'print $3\'}' % (self.interfaces[x][3])) != ''
+          loaded = get_shell_command_output('ps aux | grep \'%s\' | grep -v \'grep\' | awk {\'print $3\'}' % 
+                                            (self.interfaces[x][3])) != ''
       if loaded:
-        self.__interfaces[x] = dbus.Interface(self.get_bus().get_object(self.interfaces[x][0], self.interfaces[x][1], introspect=self.interfaces[x][4], follow_name_owner_changes=True), self.interfaces[x][2])
+        self.__interfaces[x] = dbus.Interface(self\
+                                              .get_bus()\
+                                              .get_object(self.interfaces[x][0], 
+                                                          self.interfaces[x][1], 
+                                                          introspect=self.interfaces[x][4], 
+                                                          follow_name_owner_changes=True), 
+                                              self.interfaces[x][2])
     except Exception, e:
       self.__interfaces[x] = None
 
@@ -190,7 +209,8 @@ class AbstractInterface():
   def __update_ui(self):
     windex = self.state['value']
     image = self.state['images'][windex]
-    if windex == 2 and self.state['strength'] > 0: image = self.state['images_st'][self.state['strength']]
+    if windex == 2 and self.state['strength'] > 0:
+      image = self.state['images_st'][self.state['strength']]
     self.__set_si(image)
     self.__button.set_value(self.__lcl.get_item(self.state['text'][windex]))
 
@@ -210,7 +230,9 @@ class AbstractInterface():
     return True
 
   def __show_switch_dialog(self):
-    settings_dialog = gtk.Dialog('%s' % (self.__name), None, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, (gtk.STOCK_PREFERENCES, gtk.RESPONSE_OK))
+    settings_dialog = gtk.Dialog('%s' % (self.__name), None, 
+                                 gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
+                                 (gtk.STOCK_PREFERENCES, gtk.RESPONSE_OK))
     self.state_control = ToggleControlMaemo5(self.__get_state_controls())
     self.state_control.set_active(self.state['value'])
     settings_dialog.vbox.pack_start(self.state_control.get_box(), True)
@@ -225,7 +247,7 @@ class AbstractInterface():
     settings_button = settings_dialog.action_area.get_children()[0]
     settings_button.connect('clicked', self.__show_settings_dialog)
 
-    settings_dialog.vbox.set_size_request(-1, min(350, height))
+    #settings_dialog.vbox.set_size_request(-1, min(350, height))
     settings_dialog.show_all()
     self.__processing = False
 
@@ -247,7 +269,8 @@ class AbstractInterface():
         except:
           self.switched()
           self.__update_ui()
-      elif cstate != self.state['value']: control.set_active(self.state['value'])
+      elif cstate != self.state['value']: 
+        control.set_active(self.state['value'])
 
   def __turn_mode(self, widget=None, control=None, cmode=None):
     if widget.get_active():
@@ -259,7 +282,8 @@ class AbstractInterface():
         except:
           self.switched()
           self.__update_ui()
-      elif cmode != self.state['mode']: control.set_active(self.state['mode'])
+      elif cmode != self.state['mode']: 
+        control.set_active(self.state['mode'])
 
   def __switch_state(self, new_state):
     cstate = min(1, self.state['value'])
@@ -303,5 +327,7 @@ class AbstractInterface():
 
   def __set_sai(self, key):
     if any(self.state['show']):
-      if self.state['show'][self.state['value']]: self.__set_status_area_icon(self.__name, key)
-      else: self.__set_status_area_icon(self.__name, None, False)
+      if self.state['show'][self.state['value']]:
+        self.__set_status_area_icon(self.__name, key)
+      else: 
+        self.__set_status_area_icon(self.__name, None, False)
